/**
 * Allow us to use the random number generator
 */
import java.util.Random;                                           

/**
 * Animal has some basic attributes of elements in the simulation. Animals
 * have location and color.
 * 
 * Author: Simon Parsons
 * Last modified: 23rd September 2012
 */
public abstract class Animal{

	/** 
	 * myColor is protected so that subclasses can access them directly.
	 * Not very good programming practice (but helps to illustrate private)
	 * Better would be, like location, to have API methods to handle color.
	 */
	private Point location;
    protected AnimalColor myColor;
    
	/**
	 * The constructor sets up the animal at a random location
	 */
	Animal(){
		Random ranGen = new Random();
		location = new Point(10 + ranGen.nextInt(380), 10 + ranGen.nextInt(360));
	}
	
	/**
	 * The API allows the animal's location to be altered. This uses the Point API.
	 */
	public void setLocationX(int x){
		location.setX(x);
	}

	public void setLocationY(int y){
		location.setY(y);
	}

	public int getLocationX(){
		return location.getX();
	}

	public int getLocationY(){
		return location.getY();
	}

	public AnimalColor getColor(){
		return myColor;
	}
	
	/**
	 * Abstract method
	 */
	public abstract void move();
}
