/**
 * We use swing components.
 */
import javax.swing.JFrame;                                         

/**
 * This sets up the main window for the program. It only has one field, the
 * component that handles the I/O.
 * 
 * Author: Simon Parsons
 * Last modified: 23rd September 2012
 *
 */
public class EcoFrame{
	
	/**
	 * The EcoFrame object has two data field. One is the component that does
	 * all the work, the other is a reference to the simulation for which it is
	 * managing the display.
	 */
	private SimulationComponent simCom = new SimulationComponent();
	private EcoSystem eSystem;
	
	public EcoFrame(){
		JFrame frame = new JFrame("My little ecosystem!");          
		frame.getContentPane().add(simCom);      
		frame.setSize(400,400);                                     
		frame.setVisible(true);                                    		
	}
	
	/**
	 * Allows the simulation to pass a reference to new objects that have been 
	 * added so that they can be displayed.
	 * 
	 * Right now assumes that all objects will be animals.
	 */
	public void addElementToSimulation(Animal a){
		simCom.addElement(a);
	}
	
	/**
	 * Gives us a reference to the simulation, and passes it on to the component
	 * that does the work. This latter will need to pass input back to the simulation.
	 */
	public void addSimulation(EcoSystem eSystem){
		this.eSystem = eSystem;
		simCom.addSimulation(eSystem);
	}
}