/**
 * Need this object to handle random numbers.
 */
import java.util.Random;

/**
 * A class that represents a rabbit in the EcoSystem simulation.
 * 
 * Inherits the API from Animal, but specifies color and defines its own move function.
 * 
 * Author: Simon Parsons
 * Last modified: September 23rd 2012
 */
public class Rabbit extends Animal implements Predator{

	private Direction myDirection;
	
	/** 
	 * When we create a new rabbit, set it up at a random location using the
	 * constructor for the superclass animal, and pick a color for it, restricting
	 * color choice to be black or white.
	 */	
	Rabbit(){
		super();
		Random ranGen = new Random();
		if(ranGen.nextInt(2) == 0){
			myColor = AnimalColor.BLACK;
		}
		else{
			myColor = AnimalColor.WHITE;
		}
		switch (ranGen.nextInt(4)){
		case 0:
			myDirection = Direction.NORTH;
			break;
		case 1:
			myDirection = Direction.SOUTH;
			break;
		case 2:
			myDirection = Direction.EAST;
			break;
		case 3:
			myDirection = Direction.WEST;
			break;
		default:
			System.out.println("Agh!");
		}
	}
	
	/**
	 * move has the rabbit move in the direction it is heading, wrapping
	 * around the frame where necessary.
	 * 
	 * A better implementation would have the bounds on x and y related to
	 * the size of the frame set in EcoFrame.java
	 */
	public void move(){
	    
		switch(myDirection){
		case NORTH:
			if (getLocationY() > -5){
				setLocationY(getLocationY() - 5);
			}
			else{
				setLocationY(365);
			}
			break;
		case SOUTH:
			if (getLocationY() < 365){
				setLocationY(getLocationY() + 5);
			}
			else{
				setLocationY(-5);
			}
			break;
		case EAST:
			if (getLocationX() < 385){
				setLocationX(getLocationX() + 5);
			}
			else{
				setLocationX(-10);
			}
			break;
		case WEST:
			if (getLocationX() > -10){
				setLocationX(getLocationX() - 5);
			}
			else{
				setLocationX(385);
			}
			break;
		}
	}
	
	/**
	 * Since Rabbit implements the Predator interface, there needs to be
	 * an "eat" method in Rabbit.
	 * 
	 * For now this just prints a message to the console.
	 */
	public void eat(){
		System.out.println("yum!");
	}
}